#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class MyCustomIndicator2 : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int rSIno = 50; // Default setting for RSIno
            private int volumeshares = 1000000; // Default setting for Volumeshares
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Orange), PlotStyle.TriangleUp, "Plot0"));
            Overlay				= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
            if (RSI(14, 3).Avg[0] <= RSIno
                && High[0] > High[1]
                && High[0] > High[2]
                && High[1] < High[2]
                && Low[0] > Low[1]
                && Low[1] < Low[2]
                && Close[0] > High[1]
                && Volume[0] > Volumeshares
                && Close[0] > Open[0]
                && Open[2] > Close[2]
                && Close[1] < Close[2]
                && ATR(14)[0] < (Close[0]) * (1 + -0.8))
			
			Plot0.Set(1);
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot0
        {
            get { return Values[0]; }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int RSIno
        {
            get { return rSIno; }
            set { rSIno = Math.Max(1, value); }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int Volumeshares
        {
            get { return volumeshares; }
            set { volumeshares = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private MyCustomIndicator2[] cacheMyCustomIndicator2 = null;

        private static MyCustomIndicator2 checkMyCustomIndicator2 = new MyCustomIndicator2();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public MyCustomIndicator2 MyCustomIndicator2(int rSIno, int volumeshares)
        {
            return MyCustomIndicator2(Input, rSIno, volumeshares);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public MyCustomIndicator2 MyCustomIndicator2(Data.IDataSeries input, int rSIno, int volumeshares)
        {
            if (cacheMyCustomIndicator2 != null)
                for (int idx = 0; idx < cacheMyCustomIndicator2.Length; idx++)
                    if (cacheMyCustomIndicator2[idx].RSIno == rSIno && cacheMyCustomIndicator2[idx].Volumeshares == volumeshares && cacheMyCustomIndicator2[idx].EqualsInput(input))
                        return cacheMyCustomIndicator2[idx];

            lock (checkMyCustomIndicator2)
            {
                checkMyCustomIndicator2.RSIno = rSIno;
                rSIno = checkMyCustomIndicator2.RSIno;
                checkMyCustomIndicator2.Volumeshares = volumeshares;
                volumeshares = checkMyCustomIndicator2.Volumeshares;

                if (cacheMyCustomIndicator2 != null)
                    for (int idx = 0; idx < cacheMyCustomIndicator2.Length; idx++)
                        if (cacheMyCustomIndicator2[idx].RSIno == rSIno && cacheMyCustomIndicator2[idx].Volumeshares == volumeshares && cacheMyCustomIndicator2[idx].EqualsInput(input))
                            return cacheMyCustomIndicator2[idx];

                MyCustomIndicator2 indicator = new MyCustomIndicator2();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.RSIno = rSIno;
                indicator.Volumeshares = volumeshares;
                Indicators.Add(indicator);
                indicator.SetUp();

                MyCustomIndicator2[] tmp = new MyCustomIndicator2[cacheMyCustomIndicator2 == null ? 1 : cacheMyCustomIndicator2.Length + 1];
                if (cacheMyCustomIndicator2 != null)
                    cacheMyCustomIndicator2.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheMyCustomIndicator2 = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.MyCustomIndicator2 MyCustomIndicator2(int rSIno, int volumeshares)
        {
            return _indicator.MyCustomIndicator2(Input, rSIno, volumeshares);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.MyCustomIndicator2 MyCustomIndicator2(Data.IDataSeries input, int rSIno, int volumeshares)
        {
            return _indicator.MyCustomIndicator2(input, rSIno, volumeshares);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.MyCustomIndicator2 MyCustomIndicator2(int rSIno, int volumeshares)
        {
            return _indicator.MyCustomIndicator2(Input, rSIno, volumeshares);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.MyCustomIndicator2 MyCustomIndicator2(Data.IDataSeries input, int rSIno, int volumeshares)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.MyCustomIndicator2(input, rSIno, volumeshares);
        }
    }
}
#endregion
